@@ -153,15 +153,13 @@ def setup_server(clear_old=False, repo="github"):
     """
         Setup server
     """
-    pwd = os.path.dirname(os.path.realpath(__file__))
-    project = pwd.split('/')[-1]
 
     if repo == 'github':
-        url_keys = 'https://github.com/ArabellaTech/%s/settings/keys' % project
-        url_clone = 'git@github.com:ArabellaTech/%s.git' % project
+        url_keys = 'https://github.com/ArabellaTech/%s/settings/keys' % env.app_dir
+        url_clone = 'git@github.com:ArabellaTech/%s.git' % env.app_dir
     elif repo == 'bitbucket':
-        url_keys = 'https://bitbucket.org/arabellatech/%s/admin/deploy-keys' % project
-        url_clone = 'git@bitbucket.org:arabellatech/%s.git' % project
+        url_keys = 'https://bitbucket.org/arabellatech/%s/admin/deploy-keys' % env.app_dir
+        url_clone = 'git@bitbucket.org:arabellatech/%s.git' % env.app_dir
     else:
         raise NotImplementedError('Unknown repo type')
 
@@ -178,13 +176,13 @@ def setup_server(clear_old=False, repo="github"):
     prompt(red('Press any key to continue'))
     sudo('export WORKON_HOME=/home/%s/Envs &&\
          source /usr/local/bin/virtualenvwrapper_lazy.sh &&\
-         mkvirtualenv %s --no-site-packages' % (env.remote_user, project),
+         mkvirtualenv %s --no-site-packages' % (env.remote_user, env.app_dir),
          warn_only=True, user=env.remote_user)
     sudo('cd /home/%s/ && git clone %s www' % (env.remote_user, url_clone), user=env.remote_user)
     with cd(env.remote_path):
         sudo('git checkout %s' % env.branch, user=env.remote_user)
         sudo('git pull', user=env.remote_user)
-        sudo('cd %s && ln -sf ../config/%s/yd_local_settings.py local_settings.py' % (project, env.environment),
+        sudo('cd %s && ln -sf ../config/%s/yd_local_settings.py local_settings.py' % (env.app_dir, env.environment),
              user=env.remote_user)
         sudo(env.pip + ' install -r requirements.txt', user=env.remote_user)
         sudo(env.python + ' manage.py syncdb --migrate', user=env.remote_user)
