@@ -7,13 +7,21 @@ from django.contrib.auth.models import User
 
 BUILTIN_MODULE = '__builtin__'
 CMD = 'ydcommon.management.commands.run_qunit.commands.getstatusoutput'
-CMD_VALUE = (0, 'X')
+CMD_VALUE = (0, """X
+<!--
+ Tests completed in 289 milliseconds.
+16 tests of 16 passed, 0 failed.
+-->X""")
 if sys.version_info > (3, 0):
     BUILTIN_MODULE = 'builtins'
 
 if sys.version_info > (2, 7):
     CMD = 'ydcommon.management.commands.run_qunit.subprocess.check_output'
-    CMD_VALUE = ('X')
+    CMD_VALUE = ("""X
+<!--
+ Tests completed in 289 milliseconds.
+16 tests of 16 passed, 0 failed.
+-->X""")
 
 
 class QunitTests(TestCase):
